# Text Representation

Text representation commands are used to determine how objects are printed on the Python command line.

## Other Classes

```{eval-rst}

.. toggle::

    .. automembers:: abaqus.TextRepresentation
        :recursive:
```
